# Streetlib::Vault

[![Gem Version](https://badge.fury.io/rb/streetlib-vault.svg)](https://badge.fury.io/rb/streetlib-vault)

This gem provides a class to read data from a YAML, for example to read and consume secrets within your app.

## Installation

Add this line to your application's Gemfile:

```ruby
gem 'streetlib-vault'
```

And then execute:

    $ bundle

Or install it yourself as:

    $ gem install streetlib-vault

## Usage

Suppose that you have a `config/secrets.yml` containing:

```yaml
service:
  username: foo
  password: bar
```

Then:

```ruby
result = Streetlib::Vault::Loader.load(path: "config/secrets.yml")
result.success? # => true

# The actual content is now available here:
content = result.data.content

# Here's how you can access values:
content.service.username.unwrap # => "foo"
content.service.password.unwrap # => "bar"

content.service.unwrap # => { "username" => "foo", "password" => "bar" }

content.service["username"].unwrap # => "foo"
content.service["password"].unwrap # => "bar"

content["service"]["username"].unwrap # => "foo"
content["service"]["password"].unwrap # => "bar"

content.service.something_that_does_not_exist # => raises a Streetlib::Vault::Error
```

## Notes

The following is a not exhaustive list of some keywords that cannot be used as
keys within the YAML file, because they're used as method names:

- each
- wrap
- unwrap

## Development

After checking out the repo, run `bin/setup` to install dependencies. Then, run `rake test` to run the tests. You can also run `bin/console` for an interactive prompt that will allow you to experiment.

To install this gem onto your local machine, run `bundle exec rake install`. To release a new version, update the version number in `version.rb`, and then run `bundle exec rake release`, which will create a git tag for the version, push git commits and tags, and push the `.gem` file to [rubygems.org](https://rubygems.org).

## Contributing

Bug reports and pull requests are welcome at https://bitbucket.org/simplicissimus/streetlib-vault. This project is intended to be a safe, welcoming space for collaboration, and contributors are expected to adhere to the [Contributor Covenant](http://contributor-covenant.org) code of conduct.

## License

The gem is available as open source under the terms of the [MIT License](https://opensource.org/licenses/MIT).

## Code of Conduct

Everyone interacting in the Streetlib::Vault project’s codebases, issue trackers, chat rooms and mailing lists is expected to follow the [code of conduct](https://bitbucket.org/simplicissimus/streetlib-vault/src/master/CODE_OF_CONDUCT.md).
